PCB Environment: Via Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
Via Class Reference

## Public Member Functions
| Via (const Point_2 &, uint z1, uint z2, Real r)
const Point_2 & | location () const
uint | zmin () const
uint | zmax () const
uint | z (uint i) const
uint | height () const
Real | diameter () const
Real | radius () const
Real | squared_radius () const
bool | overlaps (const WideSegment_25 &, Real clearance, Point_25 *=0) const
bool | overlaps (const Via &, Real clearance, Point_25 *=0) const
bool | contains (const Point_25 &) const
Bbox_2 | bbox () const
Circle_2 | getCircle () const
bool | onLayer (uint z) const
uint | otherEnd (uint z) const
| FIXME: We need to distinguish between the vertical path of a track and the via itself, which can extend over more layers.
Point_25 | otherEnd (const Point_25 &) const
Point_25 | zminEnd () const
Point_25 | zmaxEnd () const
void | extendTo (uint z)
void | merge (const Via &)
uint | cutLayers (uint zmin, uint zmax)
void | setRange (uint zmin, uint zmax)
std::string | str () const
PyObject * | getPy () const
PyObject * | getShortPy () const

## Static Public Member Functions
static Via | fromPy (PyObject *)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Via.hpp